@@ -16,7 +16,7 @@ use XML::LibXML::PrettyPrint;
 
 use OTRS::OPM::Maker -command;
 
-our $VERSION = 1.08;
+our $VERSION = 1.09;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -188,6 +188,10 @@ sub execute {
         $code->{type} = 'Code' . $code->{type};
         push @xml_parts, _CodeTemplate( $code->{type}, $code->{version}, $code->{function} || $code->{type} );
     }
+
+    for my $intro ( @{ $json->{intro} || [] } ) {
+        push @xml_parts, _IntroTemplate( $intro );
+    }
     
     my $xml = sprintf qq~<?xml version="1.0" encoding="utf-8" ?>
 <otrs_package version="1.0">
@@ -207,6 +211,19 @@ sub execute {
     $fh->close;
 }
 
+sub _IntroTemplate {
+    my ($intro) = @_;
+
+    my $version = $intro->{version} ? ' Version="' . $intro->{version} . '"' : '';
+    my $type    = $intro->{type};
+    my $text    = ref $intro->{text} ? join( "\n", @{ $intro->{text} } ) : $intro->{text};
+
+    return qq~    <Intro$type Type="post"$version><![CDATA[
+            $text
+        </Intro$type>
+    ~;
+}
+
 sub _CodeTemplate {
     my ($type, $version, $function) = @_;
 
@@ -350,8 +367,8 @@ sub _ColumnAdd {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -360,7 +377,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 CONFIGURATION
 
@@ -379,4 +396,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
